function [tdata,dfile] = readSEISAN(dfile,startAt,readLen)
    % READSEISAN TEMPLATE for reading a file into a ts_data object
    % tdata = readTEMPLATE(theFile) reads the entire file into an ts_data object
    % tdata = readTEMPLATE(theFile,startAt,readLen) reads part of the file
    %
    %	theFile can be a filename or an ts_file object with the filename
    %		parameter set to the correct value.  If the filename has wildcards,
    %		ts_file.read() will try to read all of the relevant files.
    %	startAt [0] is either a time (ts_datetime) or an offset in seconds from
    %		the begining of the file
    %	readLen [0] is the length in seconds to read (0=read to the file
    %	end).  If set to -1, the routine will return after reading the
    %	file information, but without reading the data;
    %
    
    % PROGRAMMERS NOTES:
    % You only need to use the values startAt and readLen if the files are very long and
    % it's much more efficient to read only part of them.  Otherwise,
    % ts_file.read(), which calls these functions, will take care of
    % cutting the data down to the right size.
    %
    % Always fill in the dfile information as much as possible with
    % information from the data file, including dfile.privateFirstTime and
    % dfile.privateLastTime
    
    %%% ALSO, GO INTO ts_file/guessFileFormat.m and put the
    %%% possible file extensions for your format in the list there
    
    error('ts_file:readSEISAN() is incomplete: no data read and no Fortran Record Separator handling.  SORRY!');
    
    %%%%%%%% START ALL read* WITH THESE LINES
    ts_debug(1,'Starting\n');
    tic;
    if ~exist('start','var'), start=0; end
    if ~exist('readLen','var'), readLen=0; end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if dfile.tzoffset,
        error('Time-zero correction should be taken care of in ts_file.read(), not here');
    end
    
    % GET FILE INFORMATION
    dfile=getFileInfo(dfile);   % If the file contains metadata information, put it in here.
    % If there isn't an appropriate parameter
    % in ts_file, put the value in the "custom"
    % cell array and note what values are in
    % the custom array in the subroutine
    % comments
    
    % IF READLEN==-1, the user just wanted the file information, don't read
    % data
    if isa(readLen,'numeric'); if readLen<0, tdata=[]; return; end; end
    
    % READ THE DATA
    tdata=readTheData(dfile,startAt,readLen);  % tdata is a ts_data object, and you should set
    % at least the data, the sampling rate and
    % the start time.
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function dfile=getFileInfo(dfile)
    ts_verbose(1,'Empty function')
end

function mh=readMainHeader(fid)
    % Line 1: network name, nchans, starttime, timelength
    line=fread(fid,'%80s');
    mh.netname=line(2:30);
    mh.nchans =line(31:30);
    year   =int(line(34:36))+1900;
    doy    =int(line(38:40));
    month  =int(line(42:43));
    day    =int(line(45:46));
    hr     =int(line(48:49));
    min    =int(line(51:52));
    sec    =float(line(54:59));
    mh.filetime   =ts_datetime(y,month,day,hr,min,sec);
    mh.timewind=float(line(61:69));
    
    % Line 2: free
    line=fread(fid,'%80s');
    
    % Lines 3-XX: station information
    iline=2;
    ich=0;
    while ich<fg.nchans,
        line=line+1;
        ich=ich+1;
        line=fread(fid,'%80s');
        sline=line(1:26)
        mh.station(ich)=readOneStation(line(1:26));
        if ich<fg.nchans,
            ich=ich+1;
            mh.station(ich)=readOneStation(line(27:52));
            if ich < fh.nchans,
                ich=ich+1;
                mh.station(ich)=readOneStation(line(53:78));
            end
        end
    end
    for i=line+1:12,  % Read in remaining (empty) lines
        line=fread(fid,'%80s');
    end
end

function st=readOneStation(line)
    st.name=line(2:5);
    st.comp=line([6 7 9]);
    st.relstarttime=float(line(11:17));
    st.dataintervallength=float(line(19:26));
end

function ch=readChannelHeader(fid)
    line=fread(fid,'%1040s');
    ch.stationname=line(1:5);
    ch.comp=line([6 7 9]);
    ch.loc =line([8 13]);
    ch.network=line([17 20]);
    year=int(line(10:12))+1900;
    doy=int(line(14:16));
    month=int(line(18:19));
    day=int(line(21:22));
    hr=int(line(24:25));
    min=int(line(27:28));
    sec=float(line(30:35));
    mh.starttime   =ts_datetime(year,month,day,hr,min,sec);
    mh.timing=line(29); % Blank is OK, 'E'=uncertain
    mh.samprate=float(line(37:43));
    mh.numsamps=float(line(44:50));
    mh.latitude=float(line(52:59));
    mh.longitude=float(line(61:69));
    mh.elevation=float(line(71:75));
    if strcmp(line(77),' '); mh.datasize=2;
    else mh.datasize=int(line(77));
    end
    %% GAIN INFORMATION FOLLOWS, IGNORED
end

function tdata=readTheData(dfile,start,readLen)
    % Put in your function to read the data file
    % All of the file information should be in dfile
    % If there are special parameters that need to be specified for your
    % file format, they should be stored in a cell array in dfile.custom,
    % and their format described in the top comments.
    
    fname =	dfile.filename;
    ts_verbose(1,'Reading XXXX file %s',fname);
    
    % If the file format needs custom parameters, they should be in
    % dfile.custom{}.  Check here to make sure they are and output an error
    % message explicitly saying what is missing if they are not.
    
    % checkCustom()
    
    % YOUR CODE GOES HERE
    % Put the data into a float32 row array (one channel per row) named "data".
    % Put the time of the first sample in the ts_time object "starttime"
    
    tdata = ts_data(data,samprate,dfile);
    tdata.starttime=startTime;  % or, if each channel has a different starttime, set each
    % one using tdata.channel(i).starttime
end

%function checkCustom()
%return;

% function [startAddress,endAddress]=calcCutAddrs(tdata)
%     numsamps = get(tdata,'numsamps');
%     samprate = get(tdata,'samprate');
%
%     if isa(start,'ts_datetime'),
%         timeOffset = start-get(tdata,'chstarttime',1);
%         startAddress = round(timeOffset*samprate +1);
%     elseif start~=0,
%         startAddress = round(start*samprate +1);
%     else
%         startAddress = 1;
%     end
%     endAddress = numsamps-startAddress+1;
%     if  readLen~=0,
%         endAddress = startAddress+(readLen*samprate) - 1;
%     end
% return;
