#include "mex.h"
#include "steim.h"
#include "steimlib.h"
#include "miniseed.h"
#include <errno.h>

#ifdef OSK
#define  ENOMEM           E_MEMFUL
#endif
/*
 * writesteim.c - returns a Steim compressed record to a Matlab call
 *
 */

// THIS WOULD BE MUCH FASTER IF IT WROTE THE ENTIRE STEIM RECORD TO FILE AT ONCE (ONLY "PROBLEM" WOULD BE TO
// HANDLE THE CLOCK DRIFT (JUST GIVE OFFSET BETWEEN EACH DATA SAMPLE?))

/* $Revision: 2009-05-28 $ */
// Called as:    [writeBlock,writesamps] = writesteim(data,numBytes,lastVal,level)

void mexFunction( int nlhs, mxArray *plhs[],
				 int nrhs, const mxArray *prhs[] )
{
	short difference, level, reserve, flip,i;
	short fpp,fpt,numBytes,frames;
	int *data, lastVal;		// assumes ints are 32-bits
	double *iSampsPtr,*dtmp;
	mwSize mrows,ncols;
	COMPWORD                  ftest ;
	SEED_data_record          *sdr ;
	gdptype                   gdp ;
	
	/* Check for proper number of arguments. */
	if(nrhs!=4) {
		mexErrMsgTxt("One input required.");
	} else if(nlhs>3) {
		mexErrMsgTxt("Too many output arguments.");
	}
	
	// 1st input = 32-bit data (one row or one column)
	i=0;
	mrows = mxGetM(prhs[i]);
	ncols = mxGetN(prhs[i]);
	if( !mxIsInt32(prhs[i]) || mxIsComplex(prhs[i]) || (mrows!=1 || ncols!=1) )
		mexErrMsgTxt("1st Input (data) must be a int32 row- or column-vector.");
	data=(int *) mxGetPr(prhs[i]);
	
	// 2nd input = number of bytes available to write to (standard matlab double)
	i++;
	mrows = mxGetM(prhs[i]);
	ncols = mxGetN(prhs[i]);
	if( !mxIsDouble(prhs[i]) || mxIsComplex(prhs[i]) || !(mrows==1 || ncols==1) )
		mexErrMsgTxt("2nd Input (numBytes) must be a double scalar.");
	numBytes=(short) *mxGetPr(prhs[i]);
				   
	// 3rd input = 32-bit last value of previous record
	i++;
	mrows = mxGetM(prhs[i]);
	ncols = mxGetN(prhs[i]);
	if( !mxIsInt32(prhs[i]) || mxIsComplex(prhs[i]) || !(mrows==1 || ncols==1) )
		mexErrMsgTxt("3rd Input (lastVal) must be an int32 scalar.");
	lastVal=*mxGetPr(prhs[i]);

	// 4th input = Steim compression level (standard matlab double)
	i++;
	mrows = mxGetM(prhs[i]);
	ncols = mxGetN(prhs[i]);
	if( !mxIsDouble(prhs[i]) || mxIsComplex(prhs[i]) || !(mrows==1 || ncols==1) )
		mexErrMsgTxt("4th Input (level) must be a double scalar.");
	level=(int) *mxGetPr(prhs[i]);
			   
	// 5th input = Is little endian? (1 or 0)
	// i++;
	// mrows = mxGetM(prhs[i]);
	// ncols = mxGetN(prhs[i]);
	// if( !mxIsDouble(prhs[i]) || mxIsComplex(prhs[i]) ||
	//     !(mrows==1 || ncols==1) ) {
	//   mexErrMsgTxt("5th Input (is little endian) must be a double scalar.");
	//  }
	//  flip=short(mxGetPr(prhs[i]);	// Output should be big-endian, tells steim code whether to flip the data

	// see if flipping is necessary (a vax or intel must flip to write big-endian order)
	ftest.b[0] = 0x12 ;
	ftest.b[1] = 0x34 ;
	ftest.b[2] = 0x56 ;
	ftest.b[3] = 0x78 ;
	if (ftest.l == 0x78563412)
		flip = 1 ;
	else
		if (ftest.l == 0x12345678)
			flip = 0 ;
	else
	{
		printf ("CPU word order cannot be processed\n") ;
		exit (0) ;
	}

	/* Create matrices for the return arguments. */
	// First output: write block,  Second output: number of data samples written

	plhs[0] = mxCreateNumericMatrix(1,fpp*16, mxINT32_CLASS, mxREAL);
	plhs[1] = mxCreateDoubleMatrix(1,1,  mxREAL);

	// Now assign variable pointers that steim.c understands
	sdr = (SEED_data_record *)mxGetPr(plhs[0]);
	iSampsPtr=mxGetPr(plhs[1]);

	// SET UP STEIM WRITING
	// These are the "standard" miniSEED Steim parameters
	difference=1;
	fpp=numBytes/64;  // Frames per package: each frame is 64 bytes
	fpt=(fpp+8)/8;
	if (level==3) {reserve=3;}
	else {reserve=2;}
	//allocate steim "compression continuity and generic data record" control structure
	if ((gdp = (gdptype)init_generic_compression (difference, fpt, fpp, level, flip, (generic_data_record *)sdr)) == NULL )
		exit (ENOMEM);

	clear_generic_compression (gdp, 0) ;			// Prepares the seed buffer
	frames=compress_generic_record (gdp,  0);
	*iSampsPtr=(double) generic_record_samples(gdp);
}
