function writeSEISAN_PZ(obj,fname)
% Write instrument response to a SEISAN Pole-Zero file
% Usage:
%   writeSEISAN_PZ(obj,fileName);
% Inputs:
%   obj         ts_response object
%	fileName	name of the file to write to.  If not specified,
%               the file will be named 'SEISAN_PZs_TiSkit'

if ~exist('fname','var'); fname='SEISAN_PZs_TiSkit'; end

ts_verbose(0,'Writing SEISAN pole-zero file %s\n',fname);
if ~strcmpi(obj.inUnits,'m'),
    ts_warning('inUnits are ''%s'', should be ''m'', trying to convert',obj.inUnits);
    obj.inUnits='m';
end

	
fid = fopen(fname,'w');
nP = length(obj.poles); nZ = length(obj.zeros);

fprintf(fid,'%3d %3d %9g\n',nP,nZ,obj.gain);
for i = 1:nP,
	fprintf(fid,'%10g %10g\n', real(obj.poles(i)), imag(obj.poles(i)));
end
for i = 1:nZ,
	fprintf(fid,'%10g %10g\n', real(obj.zeros(i)), imag(obj.zeros(i)));
end
fclose(fid);
