% Test the ts_timewindows class, which can be used to specify time windows in the
% data
%
% These windows can be used to avoid bad data segments when calculating spectra
% (or data cleaning transfer functions) using the 'baddata' field
%
% They can also be highlighted in time series plots using the 'highlight' field
%
% They can be hand-entered, or selected in tsplot
%
% Type "doc ts_timewindows" for details


% Create a list of "bad data" in a time series and calculate spectra while
% avoiding this data

tdata =  example_readWEBBdata();	% Read in seafloor BBOBS data

baddata=ts_timeWindowList('2008/01/01 10:45:00',10);   % 10s starting at specified time
baddata.add('2008/01/01 11:15:42',10);              % Add another bad data window
baddata.add('2008/01/01 11:25:00',-10);             % This window goes +- 10s from the specified time
baddata.add('2008/01/01 12:00:00',0:300:900,1);     % 1 sec windows every 5 minutes from 12:00 to 12:15
baddata.addbuffer('1m');                            % Add a buffer of 1 minute after each window
gooddata=baddata.invert(tdata);                     % Inverts the data windows
baddata                                             %#ok<NOPTS> % Print out list of "bad" windows
goodddata                                           % Print out list of "good" windows

figure(1); plot(tdata);
figure(2); plot(tdata,'highlight',baddata);
figure(3); plot(tdata,'highlight',gooddata);

% Use tsplot to extend the list of baddata
figure(4);
tsplot(tdata,'highlight',baddata);
newbaddata=TSPLOT.HIGHLIGHTS;

sdata_a=tdata.calcSpectra();
sdata_b=tdata.calcSpectra('badoffsets',badddata);
sdata_c=tdata.calcSpectra('badoffsets',newbadddata);
figure(5); plot(sdata_a,'title','all data');
figure(6); plot(sdata_b,'title','some bad data removed');
figure(7); plot(sdata_c,'title','all bad data removed');
