%% ts_file
% Time series data file class
%
%% Properties:
%  filename    - Full pathname of file containing data  (string)
%  format      - Data file format (SAC, MSEED, ...)     (string)
%  custom      - Parameters specific to the file format (cell vector)
%  readchans   - Which channels to store and display    (numeric vector)
%  ch_metadata - Channel information                    (ts_data_channel_metadata vector)
%  event       - Event information                      (ts_event)
%  firstTime   - READONLY: First time in the data file  (ts_datetime)
%  lastTime    - READONLY: Last time in the data file   (ts_datetime)
%  clockCorrs  - READONLY: [tzoffset clockdrift]        (numeric 2x1)
%  nChannels   - READONLY: Number of channels in the file (numeric)
%
%% Methods:
%  ts_file             - Creator
%  read                - Read data
%  save                - Save information to an executable file
%  ts_file.readDB      - Read data from database (organized files)
%  ts_file.listFormats - Return readable formats
%
% EXAMPLE:
f=ts_file('mafile','MSEED')  % Explicitly give file type
d=f.open()
d.plot()

f=ts_file('mafile.msd')      % Determines file type from suffix

ts_file.listFormats			% Lists the formats whith read*() functions

f=ts_file('mafile.msd')
f.firsttime
f.read(0,0)					% Interrogates file for information
f.firsttime

d=ts_file.readDB('SDS','/SDS','2011/10/14','1h','network=VU')
     							% Reads data from network VU in SeisComp database
plot(d);						% Same as d.plot()
%% See Also
% <ts_data_channel_metadata_help.html |ts_data_channel_metadata|>, <ts_event_help.html |ts_event|>,
% <ts_datetime_help.html |ts_datetime|>