function value = ts_get(field)
% TS_GET Function to get a value from the TiSkit global variables
% Usage: value = ts_get(field)
%
% Inputs
%	field   
%   'verbose'   where to output optional information:
%                 0 = nowhere, [1]=to screen 
%   'debug'     Print out debugging information? [0]=no, 1=yes
%	'dialogs',  Use dialog boxes for some messages? [0]=no, 1-yes
%	'version',  Software version number
%	'figureprops', default figureprops parameter

% 10/1/2002 Wayne Crawford
% Gets values from the global structure TISKIT_GLOBALS

ts_init;
global TISKIT_GLOBALS

if ~exist('field','var'),
    disp('*****************************************************************');
    fprintf('TiSkit version %s\n',TISKIT_GLOBALS.version);
    fprintf('verbose = %d, dialogs = %d, debug = %d\n', ...
        TISKIT_GLOBALS.verbose, TISKIT_GLOBALS.dialogs,TISKIT_GLOBALS.debug);
	disp('figureprops:');
	disp(char(TISKIT_GLOBALS.figureprops));
	return;
end

if ~ischar(field), error('fieldname must be a character string'); end

switch field,
    case 'verbose',
        value = TISKIT_GLOBALS.verbose;
    case {'dialog','dialogs'},
        value = TISKIT_GLOBALS.dialogs;
    case 'debug',
        value = TISKIT_GLOBALS.debug;
        switch value;
            case {0,1,2},
            otherwise, 
                warning(['Unknown value: ''' value '''  for field ''' field '''']);
        end
    case 'version',
        value = TISKIT_GLOBALS.version;
    case 'figureprops',
        value = TISKIT_GLOBALS.figureprops;
    case 'subplotprops',
        value = TISKIT_GLOBALS.figureprops.subplot(1);
    otherwise,
        ts_warning([field 'is an invalid field']);
end
