function ts_set(varargin)
    % TS_SET Function to set a TiSkit global variable
    % ts_set(variable,value)
    % Set the TiSkit global variables
    %%
    % Inputs
    %	variable   value
    %   'verbose'   0   don't output information
    %               1   output information to the MATLAB command window
    %   'dialogs'   1   output information to dialog boxes
    %                        (including waitbars during spectra, etc)
    %               0    no dialog boxes
    %   'debug'    [0]   Don't print out debugging information
    %               1    Print out debugging information
    %	'figureXXXX', where XXXXX is a set(ts_figureproperties) argument, allows you to
    %						set the default plotting behaviors.
    %                    Type 'set(ts_figureproperties)' for valid arguments and values
    
    % 10/1/2002 Wayne Crawford
    % Creates/modifies the global structure TISKIT_GLOBALS that has fields:
    %	verbose
    %	dialogs
    %	debug
    %	figureprops
    
    global TISKIT_GLOBALS
    if isempty(TISKIT_GLOBALS),
        ts_init;
    end
    if isempty(varargin), ts_warning('must have arguments for ts_set'); end
    
    ielem = 1;
    while ielem < length(varargin),
        field = varargin{ielem};
        values = varargin{ielem+1};
        if ~ischar(field), error('1st argument must be a fieldname'); end
        ielem = ielem+2;
        
        if strcmp(field(1:4),'plot'),
            TISKIT_GLOBALS.figureprops = set(TISKIT_GLOBALS.figureprops,field(5:end),values);
        elseif strcmp(field(1:4),'figu'),   % Actually looking for "figure", but some fields are
                                            % less than 6 characters, this
                                            % is easy way out
            TISKIT_GLOBALS.figureprops = set(TISKIT_GLOBALS.figureprops,field(7:end),values);
        else
            switch lower(field),
                case 'verbose',
                    switch values,
                        case {-1},  % Don't say ANYTHING
                            TISKIT_GLOBALS.verbose = -1;
                        case {0,'off'}, % Only important information
                            TISKIT_GLOBALS.verbose = 0;
                        case {2},       % Blabber blabber blabber blabber
                            TISKIT_GLOBALS.verbose = 2;
                        otherwise,      % Blabber on a bit
                            TISKIT_GLOBALS.verbose = 1;
                    end
                    ts_verbose(1,'Tiskit global variable VERBOSE set to %d',TISKIT_GLOBALS.verbose);
                case 'dialogs',
                    switch values,
                        case {0,'off'},
                            TISKIT_GLOBALS.dialogs = 0;
                        otherwise,
                            TISKIT_GLOBALS.dialogs = 1;
                    end
                    ts_verbose(1,'Tiskit global variable DIALOGS set to %d',TISKIT_GLOBALS.dialogs);
                case 'debug',
                    switch values,
                        case 0, TISKIT_GLOBALS.debug = 0;
                        case 1, TISKIT_GLOBALS.debug = 1;
                        case 2, TISKIT_GLOBALS.debug = 2;
                        otherwise, ts_warning('%d is an invalid option for %s',values,field);
                    end
                    ts_verbose(1,'Tiskit global variable DEBUG set to %d',TISKIT_GLOBALS.debug);
                otherwise,
                    ts_warning([field 'is an invalid field']);
            end
        end
    end
end
