function tsp_TimeGUIMod(command, value,options)
%
% Possible commands:
% 'displaydatafiles': displays all data files in a message box
% 'changedecimate':   changes the decimate value (input values from a dialog box)
% 'addchange_dfile':  add or change a device
% 'remove_dfile':     remove a device
% 'filterdata':       filter data ( input values from a dialog box)
% 'showraw':          show unfiltered data
% 'showfiltered':     show filtered data
% 'removegain':       Correct data for instrument gain (but not for
%                            transfer funct)
% 'calcspect':        Calculate spectra (input values from a dialog box)
% 'outputpicks':      Save picks in a file (create if doesn't exist)
% 'setaddress'        Set first address to plot
% 'setseglen':        Set length of data to display
% 'setplotStartEnd':  Set data to display using start and end seconds
%                            from start of current display (old name:
%                            'setplotbox')
% 'setComments':      Set text to put in comments box (may be changed by program
% 'setTitle':         Set text to put in title (won't be changed by program)
% 'setyrange',        Set y range to display ('*2','/2','A:B', or 'A');
% 'toggleautoyrange', Change if yrange is calculated automatically
% 'readData':         Read in new data
% 'lineclick':        Display the position corresponding to the cursor
%                            click
% 'savesac':          Save all data to a SAC file
% 'saveascii':        Save all data to an ASCII file

global TSPLOT_VARIABLES
global TSPLOT_DATA
global TSPLOT_DATAFILE
global TEMP_READCHANS
global APVIEW_LASTCLICK
persistent currDataStart

command=lower(command);	% Allows for any combination of caps or no
switch command,	% Allows for any combination of caps or no
    case 'displaydatafiles',
        for i = 1:TSPLOT_VARIABLES.numdevs,
            msgbox(char(TSPLOT_VARIABLES.files(i)), ...
                sprintf('Datafile %d',i));
        end
    case 'displaytimedata',
        msgbox(char(TSPLOT_DATA),'Timedata');
    case 'changedecimate',
        %		decimtype = TSPLOT_VARIABLES.timefigureprops.decimtype;
        %         switch decimtype,
        %             case 'smart',
        %                 decimval = TSPLOT_VARIABLES.timefigureprops.smartdecim;
        %             otherwise,
        %                 decimval = TSPLOT_VARIABLES.timefigureprops.regdecim;
        %                 if decimval == 1, decimtype = 'none'; end
        %         end
        [selection, ok] = listdlg('ListString',{'Smart','Regular','None'}, ...
            'SelectionMode','single', ...
            'ListSize',[240 100], ...
            'PromptString',['Decimation type (currently ' TSPLOT_DATA.figureprops.decimtype ')']);
%            'PromptString',['Decimation type (currently ' TSPLOT_VARIABLES.timefigureprops.decimtype ')']);
        if ~ok, return, end
        switch selection,
            case 3,		% None
%                TSPLOT_VARIABLES.timefigureprops.decimtype='regular';
%                TSPLOT_VARIABLES.timefigureprops.regdecim=1;
                TSPLOT_DATA.figureprops.decimtype='regular';
                TSPLOT_DATA.figureprops.regdecim=1;
            case 1,		% Smart
                answer = inputdlg({'Maximum number of points to display'},'Smart Decimation', ...
                    1,{num2str(TSPLOT_DATA.figureprops.smartdecim)});
%                    1,{num2str(TSPLOT_VARIABLES.timefigureprops.smartdecim)});
                if isempty(answer), return, end
%                TSPLOT_VARIABLES.timefigureprops.decimtype='smart';
%                TSPLOT_VARIABLES.timefigureprops.smartdecim=str2double(answer{1});
                TSPLOT_DATA.figureprops.decimtype='smart';
                TSPLOT_DATA.figureprops.smartdecim=str2double(answer{1});
            otherwise,	% Regular
                answer = inputdlg({'Decimation factor'},'Regular Decimation', ...
                    1,{num2str(TSPLOT_DATA.figureprops.regdecim)});
%                    1,{num2str(TSPLOT_VARIABLES.timefigureprops.regdecim)});
                if isempty(answer), return, end
%                TSPLOT_VARIABLES.timefigureprops.decimtype='regular';
%                TSPLOT_VARIABLES.timefigureprops.regdecim=str2double(answer{1});
                TSPLOT_DATA.figureprops.decimtype='regular';
                TSPLOT_DATA.figureprops.regdecim=str2double(answer{1});
        end
        tsp_plottime;
    case 'addchange_dfile',
        nd=TSPLOT_VARIABLES.numdevs;
        liststring=cell(nd+1,1);
        for i = 1:nd,
            liststring{i} = sprintf('Device %d: %s',i,TSPLOT_VARIABLES.files(i).filename);
        end
        liststring{nd +1} = 'New Device';
        [selection,ok] = listdlg('ListString',liststring, ...
            'SelectionMode','single', ...
            'PromptString','Choose datafile to modify');
        if ~ok, return, end
        h = tsp_DatafileGUI;
        if selection <= TSPLOT_VARIABLES.numdevs,
            itemplate = selection;
        else
            itemplate = TSPLOT_VARIABLES.numdevs;
            TSPLOT_VARIABLES.numdevs = TSPLOT_VARIABLES.numdevs + 1;
        end
        TSPLOT_DATAFILE = TSPLOT_VARIABLES.files(itemplate);
        TEMP_READCHANS = TSPLOT_VARIABLES.files(itemplate).readchans;
        tsp_DatafileGUIMod('fillGUI');
        uiwait(h);
        TSPLOT_VARIABLES.files(selection) = TSPLOT_DATAFILE;
        TSPLOT_VARIABLES.files(selection).readchans = TEMP_READCHANS;
    case 'remove_dfile',
        if TSPLOT_VARIABLES.numdevs <2,
            errordlg('You can''t remove the only device!!');
            return;
        end
        nd=TSPLOT_VARIABLES.numdevs;
        liststring=cell(nd,1);
        for i = 1:nd,
            liststring{i} = sprintf('Device %d: %s',i,get(TSPLOT_VARIABLES.files(i),'filename'));
        end
        selection = listdlg('ListString',liststring, ...
            'SelectionMode','single', ...
            'PromptString','Choose datafile to remove');
        TSPLOT_VARIABLES.numdevs = nd -1;
        for i = selection:TSPLOT_VARIABLES.numdevs,
            TSPLOT_VARIABLES.files(i) = TSPLOT_VARIABLES.files(i+1);
        end
        TSPLOT_VARIABLES.files(TSPLOT_VARIABLES.numdevs) = [];  % This actually works!
    case 'filterdata',
        local_filterdata(gcbf);
    case 'showraw',
        TSPLOT_VARIABLES.tinfo.whichtoplot = 'unfiltered';
        set(gcbo,'Checked','on');
        set(findobj(gcbf,'Tag','MenuShowFiltered'),'Checked','off');
        tsp_plottime;
    case 'showfiltered',
        TSPLOT_VARIABLES.tinfo.whichtoplot = 'filtered';
        set(gcbo,'Checked','on');
        set(findobj(gcbf,'Tag','MenuShowRaw'),'Checked','off');
        tsp_plottime;
    case 'removegain',
        if strcmp(value,'on'),
            TSPLOT_VARIABLES.timefigureprops.subplot(:).removegain=0;
            set(gcbo,'Checked','off');
        else
            TSPLOT_VARIABLES.timefigureprops.subplot(:).removegain=1;
            set(gcbo,'Checked','on');
        end
        if exist('options','var');
            if strcmp(options,'noplot'), return, end, end
        tsp_plottime;
    case 'calcspect',
        local_calcspect;
    case 'outputpicks',
        local_outputpicks;
        tsp_plottime;
    case 'setseglen',
        switch value,
            case {'*2','/2'},
                %sampfreq = TSPLOT_DATA.channel(1).samprate;
                %dataSamps = TSPLOT_DATA.channel(1).nSamples;
                %oldseglen = TSPLOT_VARIABLES.timeplot.length;
                %[pltSmps,suffix]=calcNumSamps(TSPLOT_DATA.channel(1),oldseglen);	% convert to samples
                %curraddress = calcAddress(TSPLOT_DATA.channel(1),1,TSPLOT_VARIABLES.timeplot.start);
                %if (pltSmps <= 0), pltSmps = dataSamps-curraddress+1; end
                [oldseglen,suffix] = ts_datetime.str2seconds(TSPLOT_VARIABLES.timeplot.length);
                switch value,
                    case '*2',
                        newseglen =2*oldseglen;
                    case '/2',
                        newseglen = oldseglen/2;
                end
                switch suffix,
                    case 's', newseglen = sprintf('%g',newseglen);
                    case 'm', newseglen = sprintf('%gm',newseglen/60);
                    case 'h', newseglen = sprintf('%gh',newseglen/3600);
                    case 'd', newseglen = sprintf('%gd',newseglen/86400);
                    case 'p', newseglen = sprintf('%.0fp',ceil(newseglen*TSPLOT_DATA.channel(1).samprate));
                    otherwise, newseglen = sprintf('%.0f',newseglen);
                end
            otherwise,
                test = ts_datetime.str2seconds(value);
                if (test ~= -1),
                    newseglen = value;
                end
        end
        ts_debug(1,'setting plotlength to %s',newseglen);
        TSPLOT_VARIABLES.timeplot.length=newseglen;
        %local_setseglen(newseglen);
        if exist('options','var');
            if strcmp(options,'noplot'), return, end
        end
        tsp_plottime;
    case {'setplotstartend','setplotbox'},
        if isempty(value), return, end;
        if value(1)==0 && value(2)==0,   % Plot all data
            newseglen=0;
            plotStart=0;
        else
            sampfreq = TSPLOT_DATA.channel(1).samprate;
            currPlotStart = TSPLOT_VARIABLES.timeplot.start;
            if ~isa(currPlotStart,'ts_datetime'),
                currPlotStart = round(currPlotStart);
            end
            plotStart = currPlotStart + value(1);
            plotEnd = currPlotStart + value(2);
            if (plotEnd-plotStart)*sampfreq < 5, return, end;		% Must have at least 5 samples plotted
            newseglen = plotEnd-plotStart;
            if (newseglen < .01),
                newseglen = sprintf('%.0fp',addmax-addmin);
            elseif (newseglen < 1),
                newseglen = sprintf('%.2fs',newseglen);
            elseif (newseglen < 10),
                newseglen = sprintf('%.1fs',newseglen);
            elseif (newseglen < 300),
                newseglen = sprintf('%.0fs',newseglen);
            elseif (newseglen < 3600*2),
                newseglen = sprintf('%.1fm',newseglen/60);
            elseif (newseglen < 86400*10),
                newseglen = sprintf('%.1fh',newseglen/3600);
            else
                newseglen = sprintf('%.1fd',newseglen/86400);
            end
        end
        TSPLOT_VARIABLES.timeplot.length=newseglen;
        local_setPlotStart(plotStart);
        if exist('options','var');
            if strcmp(options,'noplot'), return, end
        end
        tsp_plottime;
    case 'setcomments',
        if ischar(value)
            h = findobj(gcf,'Tag','GUIComments');
            set(h,'String',value);
        else ts_warning('Trying to set comment line to non-string value');
        end
    case 'settitle',
        if ischar(value),
            TSPLOT_VARIABLES.title=value;
        else ts_warning('Trying to set title to non-string value');
        end
    case {'setplotstart','setaddress'},%,'setdatastart'}
        %sampfreq = TSPLOT_DATA.samprate;
        plotStart = TSPLOT_VARIABLES.timeplot.start;
        seglen = ts_datetime.str2seconds(TSPLOT_VARIABLES.timeplot.length);
        switch value,
            case 'next',
                newPlotStart = plotStart+seglen;
            case 'prev',
                newPlotStart = plotStart-seglen;
            otherwise,
                if value(1) == '+',
                    newPlotStart = plotStart + ts_datetime.str2seconds(value(2:end));
                elseif value(1) == '-',
                    newPlotStart = plotStart - ts_datetime.str2seconds(value(2:end));
                else
                    newPlotStart = ts_datetime.str2seconds(value);
                end
        end
        if isnan(newPlotStart), 
            newPlotStart=plotStart; 
            warning('%s not understood, reverting to old plot Start',newPlotStart);
        end
        local_setPlotStart(newPlotStart);
        if exist('options','var');
            if strcmp(options,'noplot'), return, end;
        end
        tsp_plottime;
    case 'setyrange',
        currrange=TSPLOT_VARIABLES.timefigureprops.subplot(1).yrange;
        currymin =TSPLOT_VARIABLES.timefigureprops.subplot(1).ymin;
        ymin = NaN;
        switch value,
            case '*2',
                if ~isnan(currymin), ymin = currymin-currrange/2; end
                yrange = currrange*2;
            case '/2',
                yrange = currrange/2;
                if ~isnan(currymin), ymin = currymin+yrange/2; end
            otherwise,
                if ~any(value==':'),	% a Range was entered
                    A = sscanf(value,' %f : %f ');
                    ymin=A(1); yrange=A(2)-ymin;
                else
                    yrange = str2double(value);
                end;
        end;
        if yrange <= 0,
            uiwait(errordlg('Yrange can''t be <= 0','Error')); return;
        else
            local_setyrange(yrange,ymin);
        end;
        if exist('options','var');
            if strcmp(options,'noplot'), return, end;
        end;
        tsp_plottime;
    case 'toggleautoyrange',
        h1 = findobj(gcf,'Tag','EditYRange');
        findobj(gcf,'Tag','CheckboxAutoYRange');
        switch value,
            case 0,		%  turn off auto ranging
                %TSPLOT_VARIABLES.timefigureprops = set(TSPLOT_VARIABLES.timefigureprops,'yrange',1000);
                %yrange = get(TSPLOT_VARIABLES.timefigureprops,'chyrange',1);
                TSPLOT_VARIABLES.timefigureprops.subplot.yrange=1000;  % changes all
                yrange = TSPLOT_VARIABLES.timefigureprops.subplot(1).yrange;
                set(h1,'String',num2str(yrange));
            otherwise,
                TSPLOT_VARIABLES.timefigureprops.yrange=NaN;
                TSPLOT_VARIABLES.timefigureprops.ymin=NaN;
                TSPLOT_VARIABLES.timefigureprops.ymax=NaN;
                set(h1,'String','Auto');
        end
        if exist('options','var');
            if strcmp(options,'noplot'), return, end;
        end
        tsp_plottime;
    case {'readdata','readrecord'},
        ts_debug(1,'in readData');
        if isa(value,'ts_datetime'),
            dataStart = value;
        else
            incrementVal=TSPLOT_VARIABLES.dataLen;
            if incrementVal==0,	% We read in all of this file, read the next if possible
                incrementVal = 1;
            end
            switch value,
                case 'next',
                    dataStart = TSPLOT_VARIABLES.dataStart + incrementVal;
                case {'prev','previous'},
                    dataStart = TSPLOT_VARIABLES.dataStart - incrementVal;
                otherwise,
                    if ischar(value),
                        dataStart = ts_datetime(value);
                    else dataStart = value;
                    end
            end
        end
        if isa(dataStart,'ts_datetime'), startStr=char(dataStart);
        else startStr= sprintf(' %g seconds offset',dataStart);
        end
        ts_debug(1,'Reading data starting at %s',startStr);
        currDataStart=dataStart;
        %if dataStart < 0, errordlg('You tried to read before start of file');
        %else,
        dataLen=local_readData(dataStart);
        %end
        if TSPLOT_VARIABLES.dataLen==0,
            TSPLOT_VARIABLES.dataLen=dataLen;
        end
        if exist('options','var');
            if strcmp(options,'noplot'), return, end
        end
        tsp_plottime;
    case {'changedatalength'},
        if ischar(value),
            TSPLOT_VARIABLES.dataLen = ts_datetime(value);
        else
            TSPLOT_VARIABLES.dataLen = value;
        end
        dataLen=local_readData(currDataStart);
        TSPLOT_VARIABLES.dataLen=dataLen;
        tsp_plottime;
    case 'lineclick',   % removed local clock drift correction (too complicated, little gain)
        offsetsecs = value(1,1); y = value(1,2);
        APchan = sscanf(get(gca,'Tag'),'APchan%d');
        APVIEW_LASTCLICK.offsetsecs = offsetsecs;
        APVIEW_LASTCLICK.channel=APchan;
        plotStart = TSPLOT_VARIABLES.timeplot.start;
        dataStart = TSPLOT_DATA.channel(APchan).starttime;
        %curraddress = plotStart+offsetsecs*get(TSPLOT_DATA,'sampfreq');
        if isa(plotStart,'ts_datetime'),
            currtime=plotStart + offsetsecs;
        else
            currtime = dataStart+plotStart+offsetsecs;
        end
        %curraddress=calcAddress(TSPLOT_DATA,APchan,currtime);
        if strcmp(TSPLOT_VARIABLES.timefigureprops.subplot(APchan).removegain,'on');
            units = TSPLOT_DATA.channel(APchan).inUnits;
            if isempty(units), units='counts'; end
        else units='counts';
        end
        otext = sprintf('%s (%.0f), %g %s',char(currtime),offsetsecs,y,units);
        tsp_TimeGUIMod('setComments',otext);
        %h = findobj(gcf,'Tag','GUIComments');
        %set(h,'String',otext);
    case 'savesac',
        if TSPLOT_VARIABLES.numdevs > 1,
            errordlg('Can''t save multiple devices to one SACfile');
            return,
        end
        starttime = calcTime(TSPLOT_DATA,1,1);
        for i = 2:TSPLOT_DATA.nChannels
            if (starttime - calcTime(TSPLOT_DATA,i,1)) > 0.5/TSPLOT_DATA.samprate,
                errordlg('The channels don''t all start at the same time.'); return
            end
        end
        [filename,pathname]=uiputfile(sprintf('%02d%02d%02d_%02d%02d.sac',...
            starttime.year,starttime.month,starttime.day, ...
            starttime.hour,starttime.minute), 'SAC filename...');
        ts_writeSAC(TSPLOT_DATA,fullfile(pathname,filename));
    case 'saveascii',
        [filename,pathname]=uiputfile('tsp_data.asc','ASCII filename...');
        formatstr = [];
        for i=1:TSPLOT_DATA.nChannels
            formatstr = [formatstr '%12g ']; %#ok<AGROW>
        end
        formatstr = [formatstr '\n'];
        fid = fopen(fullfile(pathname,filename),'wt');
        fprintf(fid,formatstr,TSPLOT_DATA.data);
        fclose(fid);
    otherwise,
        error(['unknown command <' command '>']);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function local_calcspect()
global TSPLOT_VARIABLES
global TSPLOT_DATA
global TSPLOT_SPECTRA

if ~TSPLOT_DATA.issynchronized()
    error('Can only calculate spectra for synchronized data');
end
nSamples=TSPLOT_DATA.channel(1).nSamples;
samprate=TSPLOT_DATA.channel(1).samprate;
prompt = {	'Start offset (secs)'; ...
    'End offset (secs) '; ...
    'Minimum window length (secs, will adjust to 2^N samples)'; ...
    'Window type (''prol1pi'' or ''prol4pi'')'; ...
    'Allow further window control (NOT IMPLEMENTED)' };
%			'Start record (>=1)'; ...
%			'End record'; ...
if isa('TSPLOT_SPECTRA','ts_spectra'),	% calcSpect has already been run
    winsize = TSPLOT_SPECTRA.windowsize;
    wintype = TSPLOT_SPECTRA.windowtype;
else
    winsize = 2048;
    wintype = 'prol4pi';
end
startaddr = '1';
endaddr = nSamples;
%startrec = TSPLOT_VARIABLES.dataStart;
%endrec = startrec;
morecontrol = 'No';
goodans = 0;
%dataStartTime = TSPLOT_DATA.channel(1).starttime;		% BOGUS
plotStartTime = TSPLOT_VARIABLES.timeplot.start;
plotLength = ts_datetime.str2seconds(TSPLOT_VARIABLES.timeplot.length);
if plotLength == 0,
    plotEndTime = TSPLOT_DATA.channel(1).nSamples/samprate;
else
    plotEndTime = plotStartTime+ts_datetime.str2seconds(TSPLOT_VARIABLES.timeplot.length);
end

startTime = plotStartTime; endTime = plotEndTime;

while ~goodans,
    if isa(startTime,'ts_datetime'), startField = char(startTime);
    else startField = num2str(startTime); end
    if isa(endTime,'ts_datetime'), endField = char(endTime);
    else endField = num2str(endTime); end
    defans = {	startField;	endField; ...
        num2str(winsize/samprate);	wintype; ...
        morecontrol};
    %				num2str(startrec);	num2str(endrec); ...

%%
    answer = inputdlg(prompt,'Spectra calculation',1,defans);
%%

    if isempty(answer), return, end;	% User canceled dialog
    %startTime = ts_datetime(answer{1}); endTime=ts_datetime(answer{2});
    %if isa(startTime,'ts_datetime'), startOffset = startTime-dataStartTime; else, startOffset = startTime; end
    %if isa(endTime,'ts_datetime'), endoffset = endTime-dataStartTime; else, endOffset = endTime; end
    startOffset = ts_datetime.str2seconds(answer{1});
    endOffset = ts_datetime.str2seconds(answer{2});
    startaddr= 1 + floor(samprate*startOffset);
    endaddr = floor(samprate*endOffset);
    %	startrec = str2num(answer{3});
    %	endrec = str2num(answer{4});
    winsize = samprate*str2double(answer{3});
    wintype = answer{4};
    morecontrol = lower(answer{5});
    goodans = 1;
    if winsize > endaddr-startaddr, winsize=endaddr-startaddr;goodans=0; end
    if startOffset < 0,			startOffset=0;				goodans=0; end
    if endOffset <= startOffset,endOffset = startOffset+1;	goodans=0; end
    %	if endaddr > nSamples,		endaddr=nSamples;			goodans=0; end
    %	if startrec < 1,			startrec=1,					goodans=0; end
    %	if endrec<startrec,			endrec = startrec;			goodans=0; end
    logFact = ceil(log2(winsize));
    goodwinsize = 2^logFact;
    if winsize ~= goodwinsize,
        buttonname = questdlg(sprintf('MODIFIED WINDOW SIZE TO EQUAL 2^%d SAMPLES\n From: %g seconds(%d samples)\n  To:%g seconds (%d samples)\nOK?', ...
            logFact,winsize/samprate,winsize,goodwinsize/samprate,goodwinsize));
        switch buttonname,
            case 'Yes',
                ts_verbose(0,'Changing window size from %d to %d samples',winsize,goodwinsize);
                winsize = goodwinsize;
            case 'No',
                goodans=0;
            otherwise,
                return;
        end
    end
    if ~any(strcmp(wintype,{'prol1pi';'prol4pi'})), wintype='fourpi'; goodans=0; end
    if ~any(strcmp(morecontrol,{'yes';'no'})), morecontrol='no'; end
end
%
% Put modification of rec/address values section here
%
% Fill in info line here,
%if strcmp(morecontrol,'yes'), addrstr = 'custom addresses';
%else,	addstr = 'automatic addresses'; end
%if startrec == endrec, recstr = sprintf('Record %d',startrec);
%else, recstr = sprintf('Records %d-%d',startrec,endrec); end
%clear global TSPLOT_SPECTRA
%global TSPLOT_SPECTRA
raw = [];
%for recnum = startrec:endrec,
%	if recnum ~= TSPLOT_VARIABLES.dataStart
%		local_readRecord(dataStart);
%	end
dataStart = TSPLOT_VARIABLES.dataStart;
locEndAddr = endaddr;
while locEndAddr > nSamples,
    [~, raw] = TSPLOT_DATA.calcSpectra( ...
        'st',(startaddr-1)/samprate, ...
        'le',(nSamples-startaddr)/samprate, ...
        'wl',winsize/samprate, ...
        'ta',wintype, ...
        'rs', raw);
    tdata=dfile.read(dataStart,nSamples/samprate,'next');
    dataStart=get(tdata,'startTime');
    locEndAddr = locEndAddr-(nSamples-startaddr+1);
    startaddr=1;
end
%[TSPLOT_SPECTRA, raw] = TSPLOT_DATA.calcSpectra( ...
TSPLOT_SPECTRA = TSPLOT_DATA.calcSpectra( ...
    'st',(startaddr-1)/samprate, ...
    'le',(locEndAddr-startaddr)/samprate, ...
    'wl',winsize/samprate, ...
    'ta',wintype, ...
    'rs', raw);
if dataStart ~= TSPLOT_VARIABLES.dataStart,
    dfile.read(TSPLOT_VARIABLES.dataStart,nSamples/samprate);
%    tdata=dfile.read(TSPLOT_VARIABLES.dataStart,nSamples/samprate);
end
numwinds = TSPLOT_SPECTRA.nWindows;
TSPLOT_VARIABLES.spectinfo.infoline = ...
    sprintf('time offset %g-%g s, %d %d-pt (%g s) %s windows', ...
    startOffset,endOffset,numwinds,winsize,winsize/samprate,wintype);
h = findobj('Tag','tsp_FreqGUI');
if isempty(h),
    tsp_FreqGUI;
else
    figure(h);
end
%TSPLOT_SPECTRA = set(TSPLOT_SPECTRA,'plotbottomoffset',60);	% Skip the frame area
TSPLOT_SPECTRA.figureprops.bottomoffset=60;	% Skip the frame area
TSPLOT_VARIABLES.spectinfo.whichspectplot = 'spect';
tsp_plotspect;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function local_setPlotStart(plotStart)
% plotStart can either be an offset in seconds from the start of record or an ts_datetime
global TSPLOT_VARIABLES
TSPLOT_VARIABLES.timeplot.start=plotStart;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function local_setseglen(seglen)
% global TSPLOT_VARIABLES
% TSPLOT_VARIABLES.timeplot.length=seglen;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function local_setyrange(yrange,ymin)
global TSPLOT_VARIABLES
if yrange <= 0, uiwait(errordlg('Yrange can''t be <= 0','Error')); return; end
h1 = findobj(gcf,'Tag','EditYRange');
h2 = findobj(gcf,'Tag','CheckboxAutoYRange');
if isnan(ymin),
    set(h1,'String',num2str(yrange));
else
    set(h1,'String',sprintf('%g:%g',ymin,ymin+yrange));
    TSPLOT_VARIABLES.timefigureprops.subplot(:).ymin=ymin;
end
set(h2,'Value',0);
%TSPLOT_VARIABLES.timefigureprops = set(TSPLOT_VARIABLES.timefigureprops,'ymax',NaN);
%TSPLOT_VARIABLES.timefigureprops = set(TSPLOT_VARIABLES.timefigureprops,'yrange',yrange);
TSPLOT_VARIABLES.timefigureprops.subplot(:).ymax=NaN;
TSPLOT_VARIABLES.timefigureprops.subplot(:).yrange=yrange;
%TSPLOT_VARIABLES.timefigureprops	% DEBUG

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function dataLen=local_readData(dataStart)
global TSPLOT_DATA
global TSPLOT_VARIABLES
global APVIEW_FILTDATA
dialogs = ts_get('dialogs');
if dialogs,
    txt = 'Reading data ';
    if isa(dataStart,'ts_datetime'),
        txt = [txt char(dataStart)];
    else
        txt = [txt num2str(dataStart) ];
    end
    txt=[txt ', dataLength = '];
    if isa(TSPLOT_VARIABLES.dataLen,'numeric');
        txt = [txt num2str(TSPLOT_VARIABLES.dataLen) ' seconds'];
    else
        txt = [txt sscanf('%dr',TSPLOT_VARIABLES.dataLen) ' records'];
    end
    h = waitbar(0,txt);
end
ts_debug(1,'Reading data');
for i = 1:TSPLOT_VARIABLES.numdevs,
    %TSPLOT_VARIABLES.files(i)			% DEBUG
    tdatanew = read(TSPLOT_VARIABLES.files(i),dataStart,TSPLOT_VARIABLES.dataLen);
    if ~isa(TSPLOT_DATA,'ts_data'),	%First time through
        TSPLOT_DATA = tdatanew;
    else
        if i==1,
            TSPLOT_DATA = tdatanew;
        else
            TSPLOT_DATA = merge(TSPLOT_DATA,tdatanew);
        end
    end
    if dialogs, waitbar(i/TSPLOT_VARIABLES.numdevs); end
end
dataLen=TSPLOT_DATA.channel(1).nSeconds;  % NEED TO RETHINK, ONLY WORKS FOR UNIFORM CHANNEL LENGTH
if dialogs, close(h), end
TSPLOT_VARIABLES.timeplot.start=0;
TSPLOT_VARIABLES.dataStart= dataStart;
if  strcmp(TSPLOT_VARIABLES.tinfo.filt.state,'on'),
    lpc = TSPLOT_VARIABLES.tinfo.filt.lopasscorner;
    hpc = TSPLOT_VARIABLES.tinfo.filt.hipasscorner;
    np = TSPLOT_VARIABLES.tinfo.filt.npoles;
    %	fab = TSPLOT_VARIABLES.tinfo.filt.foreandback;
    haslopass = ~isempty(lpc) & ~isnan(lpc);
    hashipass = ~isempty(hpc) & ~isnan(hpc);
    if haslopass,
        if hashipass,
            if hpc<lpc,
                APVIEW_FILTDATA = filter(TSPLOT_DATA,'pass',np,hpc,lpc);
            else
                APVIEW_FILTDATA = filter(TSPLOT_DATA,'stop',np,lpc,hpc);
            end
        else
            APVIEW_FILTDATA = filter(TSPLOT_DATA,'low',np,lpc);
        end
    elseif hashipass,
        APVIEW_FILTDATA = filter(TSPLOT_DATA,'high',np,hpc);
    else
        warning('Lowpass and hipass filter corners are empty!');
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function local_outputpicks()
global TSPLOT_DATA
global TSPLOT_VARIABLES
if isempty(TSPLOT_VARIABLES.eqpick.filename),	% Create a new pick file
    [filename,pathname] = uiputfile('temp.picks','Save Pick File As');
    if filename == 0, uiwait(errordlg('No pick file created')); return, end
    TSPLOT_VARIABLES.eqpick.filename = fullfile(pathname,filename);
end
pnames = TSPLOT_VARIABLES.eqpick.phasename;
% Get the first arrival time of the set
mintime = [];
for ich = 1:TSPLOT_DATA.nChannels,
    for iphase = 1:length(pnames),
        if ~isnan(TSPLOT_VARIABLES.chan(ich).phase{iphase}.address);
            testtime = TSPLOT_VARIABLES.chan(ich).phase{iphase}.time;
            if isempty(mintime), mintime=testtime;
            elseif mintime-testtime >0, mintime=testtime;
            end
        end
    end
end
fid=fopen(TSPLOT_VARIABLES.eqpick.filename,'at');
fprintf(fid,'%d: %s\n',TSPLOT_VARIABLES.eqpick.numsaved+1,char(mintime));
ich = 0;
for idev = 1:TSPLOT_VARIABLES.numdevs,
    for idevch = 1:length(TSPLOT_VARIABLES.files(idev).readchans),
        ich = ich+1; gotphase = 0;
        for iphase = 1:length(pnames),
            if ~isnan(TSPLOT_VARIABLES.chan(ich).phase{iphase}.address), gotphase = 1; end
        end
        if gotphase,
            fprintf(fid,'%-4.3s%02d: ', ...
                get(TSPLOT_VARIABLES.files(idev),'instname'), ...
                TSPLOT_VARIABLES.files(idev).readchans(idevch));
            
            for iphase = 1:length(pnames),
                %temp = TSPLOT_VARIABLES.chan(ich).phase;
                if ~isnan(TSPLOT_VARIABLES.chan(ich).phase{iphase}.address),
                    tmp = TSPLOT_VARIABLES.chan(ich).phase{iphase};
                    fprintf(fid,'%s%s%s%d_%07.2f ',pnames{iphase}, ...
                        tmp.type,tmp.direction, ...
                        tmp.quality,tmp.time-mintime);
                else
                    fprintf(fid,'%13s','');
                end
                TSPLOT_VARIABLES.chan(ich).phase{iphase}=eventarrival;
            end
            fprintf(fid,'\n');
        end
    end
end
fprintf(fid,'\n');
fclose(fid);
TSPLOT_VARIABLES.eqpick.numsaved = TSPLOT_VARIABLES.eqpick.numsaved+1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function local_filterdata(cbf)
global TSPLOT_DATA
global TSPLOT_VARIABLES
prompt = {'Hipass corner frequency (Hz)'; ...
    'Lowpass corner frequency (Hz)'; ...
    'Number of poles'; ...
    'Filter backwards and forwards? [''yes'',''no''] (doubles # poles)'};
hpc = TSPLOT_VARIABLES.tinfo.filt.hipasscorner;
lpc = TSPLOT_VARIABLES.tinfo.filt.lopasscorner;
np = TSPLOT_VARIABLES.tinfo.filt.npoles;
fab = TSPLOT_VARIABLES.tinfo.filt.foreandback;
defans = {	num2str(hpc); ...
    num2str(lpc); ...
    num2str(np); ...
    fab};
answer = inputdlg(prompt,'',1,defans);
if isempty(answer), return, end
hpc = str2double(answer{1}); lpc = str2double(answer{2}); np = str2double(answer{3}); fab = answer{4};
global APVIEW_FILTDATA
haslowpass = ~isempty(lpc) & ~isnan(lpc);
hashighpass = ~isempty(hpc) & ~isnan(hpc);
if haslowpass,
    if hashighpass,
        if hpc<lpc,
            APVIEW_FILTDATA = filter(TSPLOT_DATA,'pass',np,hpc,lpc);
        else
            APVIEW_FILTDATA = filter(TSPLOT_DATA,'stop',np,lpc,hpc);
        end
    else
        APVIEW_FILTDATA = filter(TSPLOT_DATA,'low',np,lpc);
    end
elseif hashighpass
    APVIEW_FILTDATA = filter(TSPLOT_DATA,'high',np,hpc);
else
    warning('No lowpass or hipass corner frequency!');
end
TSPLOT_VARIABLES.tinfo.filt.hipasscorner = hpc;
TSPLOT_VARIABLES.tinfo.filt.lopasscorner = lpc;
TSPLOT_VARIABLES.tinfo.filt.npoles = np;
TSPLOT_VARIABLES.tinfo.filt.foreandback = fab;
TSPLOT_VARIABLES.tinfo.filt.state = 'on';
TSPLOT_VARIABLES.tinfo.whichtoplot = 'filtered';
set(findobj(cbf,'Tag','MenuShowFiltered'),'Enable','on');
set(findobj(cbf,'Tag','MenuShowFiltered'),'Checked','on');
set(findobj(cbf,'Tag','MenuShowRaw'),'Checked','off');
tsp_plottime;
